@@ -1,11 +1,13 @@
 """A Python module for interacting and consuming responses from Slack."""
 
 import logging
-from typing import Union
+from typing import Any, Optional, TypeVar, Union, overload
 
 import slack_sdk.errors as e
 from .internal_utils import _next_cursor_is_present
 
+T = TypeVar("T")
+
 
 class SlackResponse:
     """An iterable container of response data.
@@ -76,9 +78,7 @@ class SlackResponse:
     def __str__(self):
         """Return the Response data if object is converted to a string."""
         if isinstance(self.data, bytes):
-            raise ValueError(
-                "As the response.data is binary data, this operation is unsupported"
-            )
+            raise ValueError("As the response.data is binary data, this operation is unsupported")
         return f"{self.data}"
 
     def __contains__(self, key: str) -> bool:
@@ -96,13 +96,9 @@ class SlackResponse:
             The value from data or None.
         """
         if isinstance(self.data, bytes):
-            raise ValueError(
-                "As the response.data is binary data, this operation is unsupported"
-            )
+            raise ValueError("As the response.data is binary data, this operation is unsupported")
         if self.data is None:
-            raise ValueError(
-                "As the response.data is empty, this operation is unsupported"
-            )
+            raise ValueError("As the response.data is empty, this operation is unsupported")
         return self.data.get(key, None)
 
     def __iter__(self):
@@ -139,9 +135,7 @@ class SlackResponse:
             StopIteration: If 'next_cursor' is not present or empty.
         """
         if isinstance(self.data, bytes):
-            raise ValueError(
-                "As the response.data is binary data, this operation is unsupported"
-            )
+            raise ValueError("As the response.data is binary data, this operation is unsupported")
         self._iteration += 1
         if self._iteration == 1:
             return self
@@ -149,9 +143,7 @@ class SlackResponse:
             params = self.req_args.get("params", {})
             if params is None:
                 params = {}
-            next_cursor = self.data.get("response_metadata", {}).get(
-                "next_cursor"
-            ) or self.data.get("next_cursor")
+            next_cursor = self.data.get("response_metadata", {}).get("next_cursor") or self.data.get("next_cursor")
             params.update({"cursor": next_cursor})
             self.req_args.update({"params": params})
 
@@ -166,6 +158,14 @@ class SlackResponse:
         else:
             raise StopIteration
 
+    @overload
+    def get(self, key: str, default: None = None) -> Optional[Any]:
+        ...
+
+    @overload
+    def get(self, key: str, default: T) -> T:
+        ...
+
     def get(self, key, default=None):
         """Retrieves any key from the response data.
 
@@ -178,9 +178,7 @@ class SlackResponse:
             The value from data or the specified default.
         """
         if isinstance(self.data, bytes):
-            raise ValueError(
-                "As the response.data is binary data, this operation is unsupported"
-            )
+            raise ValueError("As the response.data is binary data, this operation is unsupported")
         if self.data is None:
             return None
         return self.data.get(key, default)
@@ -195,11 +193,7 @@ class SlackResponse:
         Raises:
             SlackApiError: The request to the Slack API failed.
         """
-        if (
-            self.status_code == 200
-            and self.data
-            and (isinstance(self.data, bytes) or self.data.get("ok", False))
-        ):
+        if self.status_code == 200 and self.data and (isinstance(self.data, bytes) or self.data.get("ok", False)):
             return self
         msg = f"The request to the Slack API failed. (url: {self.api_url})"
         raise e.SlackApiError(message=msg, response=self)
